@@ -182,7 +182,7 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
         settings.LOCKS.release(key)
 
 
-class NotImplementation(Exception):
+class NotImplement(Exception):
     def __init__(self):
         super().__init__('Нет рееализации !!!!!!')
 
@@ -297,4 +297,5 @@ def get_list_nums_key_dict(data):
 
 class Wrapper:
     def __init__(self, **kwargs):
-        self.__dict__.update(kwargs)
+        for k, v in kwargs.items():
+            setattr(self, k, v() if callable(v) else v)
