@@ -7,9 +7,17 @@ def getOrElse(default, value):
     else:
         return default
 
-red='red'
 blue='blue'
+closed='closed'
+doing='doing'
 green='green'
+made='made'
+new='new'
+new_man='new_man'
+red='red'
+restarted='restarted'
+started='started'
+transferred='transferred'
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
     if blink:
