@@ -31,10 +31,15 @@ class AuditQuerySet(CommonQuerySet):
         if visibleMode == "hide":
             res = super().update(deleted_at=timezone.now())
         elif visibleMode == "visible":
+            logger.warning(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!Mode visibleMode={visibleMode} DEPRECATED !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
             res = super().update(deleted_at=None)
 
         return res
 
+    def soft_restore(self):
+        res = super().update(deleted_at=None)
+        return res
+
     def hard_delete(self):
         res = super().delete()
         return res
@@ -45,6 +50,11 @@ class AuditQuerySet(CommonQuerySet):
     def dead(self):
         return self.exclude(deleted_at=None)
 
+    def update(self, **kwargs):
+        if kwargs.get('lastmodified') == None:
+            setAttr(kwargs, 'lastmodified', timezone.now())
+        return super().update(**kwargs)
+
 
 class AuditManager(CommonManager):
     def __init__(self, *args, **kwargs):
@@ -73,6 +83,7 @@ class Manager(CommonManager):
     def get_queryset(self):
         return AuditQuerySet(model=self.model)
 
+
 class AuditModel(Model):
     id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     deleted_at = DateTimeField(verbose_name="Дата мягкого удаления", null=True, blank=True, db_index=True)
@@ -118,16 +129,20 @@ class AuditModel(Model):
     objects = AuditManager()
     all_objects = AuditManager(alive_only=False)
 
+
 class Dbl_spacesValue(Transform):
     lookup_name = 'delete_dbl_spaces'
     function = 'delete_dbl_spaces'
 
+
 CharField.register_lookup(Dbl_spacesValue)
 TextField.register_lookup(Dbl_spacesValue)
 
+
 class Trim_Value(Transform):
     lookup_name = 'trim'
     function = 'trim'
 
+
 CharField.register_lookup(Trim_Value)
 TextField.register_lookup(Trim_Value)
