@@ -10,7 +10,6 @@ from django.forms import model_to_dict
 from isc_common import setAttr, delAttr
 from isc_common.auth.http.LoginRequets import LoginRequest
 from isc_common.auth.models.user import User
-from isc_common.bit import IsBitOn
 from isc_common.fields.description_field import DescriptionField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
@@ -58,7 +57,7 @@ class MessagesManager(CommonTreeGridManager):
 
     @staticmethod
     def get_tracker_bot():
-        key='MessagesManager.get_tracker_bot'
+        key = 'MessagesManager.get_tracker_bot'
         settings.LOCKS.acquire(key)
         tracker_bot, _ = User.objects.get_or_create(username='tracker_bot', last_name='Бот (Дела)', password='1234567890', props=User.props.bot, deliting=False, editing=False)
         settings.LOCKS.release(key)
@@ -312,13 +311,12 @@ class MessagesManager(CommonTreeGridManager):
         tuple_ids = request.get_tuple_ids()
         with transaction.atomic():
             for id, mode in tuple_ids:
+                message = Messages.objects.get(id=id)
                 if mode == 'hide':
-                    message = super().get(id=id)
                     if not request.is_admin and not request.is_develop and message.user.id != request.user_id:
                         raise Exception(f'Удаление может выполнить только автор.')
                     message.soft_delete()
                 else:
-                    message = super().get(id=id)
                     if not message.user.props.bot.is_set:
                         if not request.is_admin and not request.is_develop and message.user.id != request.user_id:
                             raise Exception(f'Удаление может выполнить только автор.')
@@ -327,16 +325,15 @@ class MessagesManager(CommonTreeGridManager):
                     qty, _ = message.delete()
 
                     if request.user_id != message.user.id:
-                        user = User.objects.get(id=request.user_id)
-                        if not IsBitOn(message.user.props, 0):
+                        if not message.user.props.bot.is_set:
                             LoginRequest.send_bot_message(user=message.to_whom.id,
                                                           bot=MessagesManager.get_tracker_bot(),
                                                           message=f'<h3>Удаление дела:</h3> #{message.guid}'
                                                                   f'<p/>Тема: {message.theme.full_name}'
-                                                                  f'<p/>{MessagesManager.get_border(message.message, user)}'
+                                                                  f'<p/>{MessagesManager.get_border(message.message, request.user)}'
                                                                   f'<p/>Статус: {message.state.name}'
                                                                   f'''<p/>Важность: {message.importance.name if message.importance else 'Не определена'}'''
-                                                                  f'<p/>Удалил: {user.get_short_name}'
+                                                                  f'<p/>Удалил: {request.user.get_short_name}'
                                                           )
                     res += qty
         return res
